:math:`x(n) \longleftrightarrow \sum_{m=-\infty}^{\infty} X(\frac{\Omega}{2 \pi \Delta_{t}} - \frac{m}{\Delta_{t}})`

:math:`x(a n) \longleftrightarrow \frac{\sum_{m=-\infty}^{\infty} X(\frac{\Omega}{2 \pi \Delta_{t} a} - \frac{m}{\Delta_{t} a})}{\left|{a}\right|}`

:math:`x(- m + n) \longleftrightarrow \sum_{p=-\infty}^{\infty} X(\frac{\Omega}{2 \pi \Delta_{t}} - \frac{p}{\Delta_{t}}) e^{- \frac{\mathrm{j} \Omega m}{\Delta_{t}}} e^{\frac{2 \mathrm{j} \pi m p}{\Delta_{t}}}`

:math:`\cos{\left(\Omega_{0} n \right)} \longleftrightarrow \frac{\sum_{m=-\infty}^{\infty} \delta\left(\frac{\Omega}{2 \pi \Delta_{t}} - \frac{\Omega_{0}}{2 \pi \Delta_{t}} - \frac{m}{\Delta_{t}}\right)}{2 \Delta_{t}} + \frac{\sum_{m=-\infty}^{\infty} \delta\left(\frac{\Omega}{2 \pi \Delta_{t}} + \frac{\Omega_{0}}{2 \pi \Delta_{t}} - \frac{m}{\Delta_{t}}\right)}{2 \Delta_{t}}`

:math:`\sin{\left(\Omega_{0} n \right)} \longleftrightarrow - \frac{\mathrm{j} \sum_{m=-\infty}^{\infty} \delta\left(\frac{\Omega}{2 \pi \Delta_{t}} - \frac{\Omega_{0}}{2 \pi \Delta_{t}} - \frac{m}{\Delta_{t}}\right)}{2 \Delta_{t}} + \frac{\mathrm{j} \sum_{m=-\infty}^{\infty} \delta\left(\frac{\Omega}{2 \pi \Delta_{t}} + \frac{\Omega_{0}}{2 \pi \Delta_{t}} - \frac{m}{\Delta_{t}}\right)}{2 \Delta_{t}}`

:math:`e^{\mathrm{j} \Omega_{0} n} \longleftrightarrow \frac{\sum_{m=-\infty}^{\infty} \delta\left(\frac{\Omega}{2 \pi \Delta_{t}} - \frac{\Omega_{0}}{2 \pi \Delta_{t}} - \frac{m}{\Delta_{t}}\right)}{\Delta_{t}}`

:math:`1 \longleftrightarrow \frac{\sum_{m=-\infty}^{\infty} \delta\left(\frac{\Omega}{2 \pi \Delta_{t}} - \frac{m}{\Delta_{t}}\right)}{\Delta_{t}}`

:math:`\delta\left[n\right] \longleftrightarrow 1`

:math:`\delta\left[- m + n\right] \longleftrightarrow e^{- \mathrm{j} \Omega m}`

:math:`u\left[n\right] \longleftrightarrow \frac{e^{\mathrm{j} \Omega}}{e^{\mathrm{j} \Omega} - 1} + \frac{\sum_{m=-\infty}^{\infty} \delta\left(\frac{\Omega}{2 \pi \Delta_{t}} - \frac{m}{\Delta_{t}}\right)}{2 \Delta_{t}}`

:math:`n u\left[n\right] \longleftrightarrow \frac{e^{\mathrm{j} \Omega}}{e^{2 \mathrm{j} \Omega} - 2 e^{\mathrm{j} \Omega} + 1} + \frac{\mathrm{j} \sum_{m=-\infty}^{\infty} \delta^{\left( 1 \right)}\left( \frac{\Omega}{2 \pi \Delta_{t}} - \frac{m}{\Delta_{t}} \right)}{4 \pi \Delta_{t}^{2}}`

:math:`\mathop{\mathrm{sign}}\left[n\right] \longleftrightarrow \frac{2 e^{\mathrm{j} \Omega}}{e^{\mathrm{j} \Omega} - 1}`

:math:`\alpha^{- n} u\left[n\right] \longleftrightarrow \frac{\alpha e^{\mathrm{j} \Omega}}{\alpha e^{\mathrm{j} \Omega} - 1}`

:math:`\mathop{\mathrm{rect}}\left[n\right] \longleftrightarrow 1`

:math:`\mathop{\mathrm{rect}}\left[\frac{n}{N_{o}}\right] \longleftrightarrow \frac{\sin{\left(\frac{N_{o} \Omega}{2} \right)}}{\sin{\left(\frac{\Omega}{2} \right)}}`

:math:`\mathop{\mathrm{rect}}\left[\frac{n}{N_{e}}\right] \longleftrightarrow \frac{e^{\frac{\mathrm{j} \Omega}{2}} \sin{\left(\frac{N_{e} \Omega}{2} \right)}}{\sin{\left(\frac{\Omega}{2} \right)}}`

:math:`\mathrm{sincn}{\left(n \right)} \longleftrightarrow \sum_{m=-\infty}^{\infty} \mathop{\mathrm{rect}}\left[\frac{\Omega}{2 \pi} - m\right]`

:math:`\mathrm{sincn}{\left(K n \right)} \longleftrightarrow \frac{\sum_{m=-\infty}^{\infty} \mathop{\mathrm{rect}}\left[\frac{\Omega}{2 \pi K} - \frac{m}{K}\right]}{K}`

:math:`\mathrm{sincn}^{2}{\left(K n \right)} \longleftrightarrow \frac{\sum_{m=-\infty}^{\infty} \operatorname{tri}{\left(\frac{\Omega}{2 \pi K} - \frac{m}{K} \right)}}{K}`

:math:`\mathrm{sincu}{\left(K n \right)} \longleftrightarrow \frac{\pi \sum_{m=-\infty}^{\infty} \mathop{\mathrm{rect}}\left[\frac{\Omega}{2 K} - \frac{\pi m}{K}\right]}{K}`

